FabIO Package
=============

.. toctree::
   :maxdepth: 4
	

:mod:`fabio` Package
--------------------

.. automodule:: fabio
    :members: open, open_series, register, benchmarks, tests

:mod:`fabio.fabioimage` Module
------------------------------

.. automodule:: fabio.fabioimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.fabioutils` Module
------------------------------

.. automodule:: fabio.fabioutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.file_series` Module
-------------------------------

.. automodule:: fabio.file_series
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.openimage` Module
-----------------------------

.. automodule:: fabio.openimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.adscimage` Module
-----------------------------

.. automodule:: fabio.adscimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.binaryimage` Module
-------------------------------

.. automodule:: fabio.binaryimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.bruker100image` Module
----------------------------------

.. automodule:: fabio.bruker100image
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.brukerimage` Module
-------------------------------

.. automodule:: fabio.brukerimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.cbfimage` Module
----------------------------

.. automodule:: fabio.cbfimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.dm3image` Module
----------------------------

.. automodule:: fabio.dm3image
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.dtrekimage` Module
------------------------------

.. automodule:: fabio.dtrekimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.edfimage` Module
----------------------------

.. automodule:: fabio.edfimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.eigerimage` Module
------------------------------

.. automodule:: fabio.eigerimage
    :members:
    :undoc-members:
    :show-inheritance:
    
:mod:`fabio.fit2dimage` Module
------------------------------

.. automodule:: fabio.fit2dimage
    :members:
    :undoc-members:
    :show-inheritance:
    
:mod:`fabio.fit2dmaskimage` Module
----------------------------------

.. automodule:: fabio.fit2dmaskimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.fit2dspreadsheetimage` Module
-----------------------------------------

.. automodule:: fabio.fit2dspreadsheetimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.GEimage` Module
---------------------------

.. automodule:: fabio.GEimage
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`fabio.hdf5image` Module
-----------------------------

.. automodule:: fabio.hdf5image
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.HiPiCimage` Module
------------------------------

.. automodule:: fabio.HiPiCimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.kcdimage` Module
----------------------------

.. automodule:: fabio.kcdimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.mar345image` Module
-------------------------------

.. automodule:: fabio.mar345image
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.mrcimage` Module
----------------------------

.. automodule:: fabio.mrcimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.marccdimage` Module
-------------------------------

.. automodule:: fabio.marccdimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.numpyimage` Module
------------------------------

.. automodule:: fabio.numpyimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.OXDimage` Module
----------------------------

.. automodule:: fabio.OXDimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.pilatusimage` Module
--------------------------------

.. automodule:: fabio.pilatusimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.pixiimage` Module
-----------------------------

.. automodule:: fabio.pixiimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.pnmimage` Module
----------------------------

.. automodule:: fabio.pnmimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.raxisimage` Module
------------------------------

.. automodule:: fabio.raxisimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.tifimage` Module
----------------------------

.. automodule:: fabio.tifimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.xsdimage` Module
----------------------------

.. automodule:: fabio.xsdimage
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.compression` Module
-------------------------------

.. automodule:: fabio.compression
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.converters` Module
------------------------------

.. automodule:: fabio.converters
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.datIO` Module
-------------------------

.. automodule:: fabio.datIO
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.TiffIO` Module
--------------------------

.. automodule:: fabio.TiffIO
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fabio.readbytestream` Module
----------------------------------

.. automodule:: fabio.readbytestream
    :members:
    :undoc-members:
    :show-inheritance:
   